aboutsummaryrefslogtreecommitdiffstats
path: root/packet-bxxp.c
diff options
context:
space:
mode:
authorRichard Sharpe <sharpe@ns.aus.com>2000-10-07 04:48:40 +0000
committerRichard Sharpe <sharpe@ns.aus.com>2000-10-07 04:48:40 +0000
commit11f7f6651527387a37483d687a836b5a7fced14e (patch)
tree3b584d99cad755d8a2f7f5c9fb4fec38b27428f4 /packet-bxxp.c
parente69b5278aaddce2af02174afe0515adceb841973 (diff)
Squash one more little bug where I wasn't handling the MIME header
properly if a BXXP message occurrect after a SEQ but in the same segment. svn path=/trunk/; revision=2479
Diffstat (limited to 'packet-bxxp.c')
-rw-r--r--packet-bxxp.c12
1 files changed, 7 insertions, 5 deletions
diff --git a/packet-bxxp.c b/packet-bxxp.c
index 27660b9141..b856aaf95b 100644
--- a/packet-bxxp.c
+++ b/packet-bxxp.c
@@ -1,7 +1,7 @@
/* packet-bxxp.c
* Routines for BXXP packet disassembly
*
- * $Id: packet-bxxp.c,v 1.6 2000/10/05 13:13:49 sharpe Exp $
+ * $Id: packet-bxxp.c,v 1.7 2000/10/07 04:48:40 sharpe Exp $
*
* Copyright (c) 2000 by Richard Sharpe <rsharpe@ns.aus.com>
*
@@ -919,7 +919,9 @@ dissect_bxxp_tree(tvbuff_t *tvb, int offset, packet_info *pinfo,
pl_size = MIN(request_val->size, tvb_length_remaining(tvb, offset));
- if (pl_size == 0) { /* The whole of the rest must be payload */
+ /* FIXME: May be redundent ... */
+
+ if (pl_size == 0 && offset == st_offset) { /* The whole of the rest must be payload */
pl_size = tvb_length_remaining(tvb, offset); /* Right place ? */
@@ -935,9 +937,9 @@ dissect_bxxp_tree(tvbuff_t *tvb, int offset, packet_info *pinfo,
* another message here, then handle it correctly as well.
*/
/* If the pl_size == 0 and the offset == 0?, then we have not processed
* anything in this frame above, so we better treat all this data as
* payload to avoid recursion loops
*/
if (pl_size == 0 && offset == st_offset)
@@ -935,9 +937,9 @@ dissect_bxxp_tree(tvbuff_t *tvb, int offset, packet_info *pinfo,
* another message here, then handle it correctly as well.
*/
- /* If the pl_size == 0 and the offset == 0?, then we have not processed
- * anything in this frame above, so we better treat all this data as
- * payload to avoid recursion loops
+ /* If the pl_size == 0 and the offset == st_offset, then we have not
+ * processed anything in this frame above, so we better treat all this
+ * data as payload to avoid recursion loops
*/
if (pl_size == 0 && offset == st_offset)